@@ -194,80 +194,6 @@ get_preferred_height (BonoboDockItem *dock_item)
   return preferred_height;
 }
 
-static gboolean
-bonobo_gtk_container_focus_move (GtkContainer     *container,
-				 GList            *children,
-				 GtkDirectionType  direction)
-{
-  GtkWidget *focus_child;
-  GtkWidget *child;
-
-  focus_child = container->focus_child;
-
-  while (children)
-    {
-      child = children->data;
-      children = children->next;
-
-      if (!child)
-	continue;
-      
-      if (focus_child)
-        {
-          if (focus_child == child)
-            {
-              focus_child = NULL;
-
-		if (gtk_widget_child_focus (child, direction))
-		  return TRUE;
-            }
-        }
-      else if (GTK_WIDGET_DRAWABLE (child) &&
-               gtk_widget_is_ancestor (child, GTK_WIDGET (container)))
-        {
-          if (gtk_widget_child_focus (child, direction))
-            return TRUE;
-        }
-    }
-
-  return FALSE;
-}
-
-/*
- * FIXME: this is a hack because in un-docked toolbars
- * bad things happen if we traverse up the GdkWindow
- * hierarchy doing dumb things like GtkContainer does.
- */
-gboolean
-bonobo_widget_clobber_focus (GtkWidget        *widget,
-			     GtkDirectionType  direction)
-{
-  gboolean has_focus_chain;
-  GList *focus_chain = NULL;
-  GList *children = NULL;
-  gboolean return_val = FALSE;
-  GtkContainer *container;
-
-  container = GTK_CONTAINER (widget);
-
-  has_focus_chain = gtk_container_get_focus_chain (
-	  container, &focus_chain);
-
-  if (has_focus_chain)
-    children = g_list_copy (focus_chain);
-  else
-    children = gtk_container_get_children (container);
-
-  if (direction == GTK_DIR_TAB_BACKWARD || direction == GTK_DIR_LEFT)
-    children = g_list_reverse (children);
-
-  return_val = bonobo_gtk_container_focus_move (container, children, direction);
-
-  g_list_free (children);
-
-  return return_val;
-}
-
 static void
 bonobo_dock_item_class_init (BonoboDockItemClass *class)
 {
@@ -374,7 +300,6 @@ bonobo_dock_item_class_init (BonoboDockItemClass *class)
 
   widget_class->map = bonobo_dock_item_map;
   widget_class->unmap = bonobo_dock_item_unmap;
-  widget_class->focus = bonobo_widget_clobber_focus;
   widget_class->realize = bonobo_dock_item_realize;
   widget_class->unrealize = bonobo_dock_item_unrealize;
   widget_class->style_set = bonobo_dock_item_style_set;
@@ -605,12 +530,8 @@ bonobo_dock_item_realize (GtkWidget *widget)
   if (di->_priv->grip)
     gtk_widget_set_parent_window (di->_priv->grip, di->bin_window);
 
-#ifdef HAVE_GTK_MULTIHEAD
-  root_window = gdk_screen_get_root_window (
-			gdk_drawable_get_screen (GDK_DRAWABLE (widget->window)));
-#else
-  root_window = gdk_get_default_root_window ();
-#endif
+  root_window = gdk_screen_get_root_window
+	  (gdk_drawable_get_screen (GDK_DRAWABLE (widget->window)));
   
   attributes.x = 0;
   attributes.y = 0;
@@ -780,14 +701,18 @@ bonobo_dock_item_size_allocate (GtkWidget     *widget,
 
 	  grip_alloc.x = grip_alloc.y = 0;
 
-          if (di->orientation == GTK_ORIENTATION_HORIZONTAL) {
-            child_allocation.x += DRAG_HANDLE_SIZE;
-
-            grip_alloc.width = DRAG_HANDLE_SIZE;
-          } else {
-            child_allocation.y += DRAG_HANDLE_SIZE;
-
+          if (di->orientation != GTK_ORIENTATION_HORIZONTAL) {
             grip_alloc.height = DRAG_HANDLE_SIZE;
+            child_allocation.y += DRAG_HANDLE_SIZE;
+          } else {
+            grip_alloc.width = DRAG_HANDLE_SIZE;
+	    if (gtk_widget_get_direction (widget) == GTK_TEXT_DIR_LTR) {
+	      child_allocation.x += DRAG_HANDLE_SIZE;
+	    } else {
+	      GtkRequisition child_requisition;
+	      gtk_widget_get_child_requisition (child, &child_requisition);
+	      grip_alloc.x = child_requisition.width;
+	    }
 	  }
 
 	  gtk_widget_size_allocate (di->_priv->grip, &grip_alloc);
@@ -855,35 +780,10 @@ bonobo_dock_item_paint (GtkWidget      *widget,
 {
   GtkBin *bin;
   BonoboDockItem *di;
-  guint width;
-  guint height;
-  guint border_width;
-  gint drag_handle_size = DRAG_HANDLE_SIZE;
-
-  if (!BONOBO_DOCK_ITEM_NOT_LOCKED (widget))
-    drag_handle_size = 0;
 
   bin = GTK_BIN (widget);
   di = BONOBO_DOCK_ITEM (widget);
 
-  border_width = GTK_CONTAINER (di)->border_width;
-
-  if (di->is_floating)
-    {
-      width = bin->child->allocation.width + 2 * border_width;
-      height = bin->child->allocation.height + 2 * border_width;
-    }
-  else if (di->orientation == GTK_ORIENTATION_HORIZONTAL)
-    {
-      width = widget->allocation.width - drag_handle_size;
-      height = widget->allocation.height;
-    }
-  else
-    {
-      width = widget->allocation.width;
-      height = widget->allocation.height - drag_handle_size;
-    }
-
   if (!event)
     gtk_paint_box(widget->style,
                   di->bin_window,
@@ -928,7 +828,9 @@ bonobo_dock_item_expose (GtkWidget      *widget,
 static void
 bonobo_dock_item_drag_end (BonoboDockItem *di)
 {
-  gdk_pointer_ungrab (GDK_CURRENT_TIME);
+  gdk_display_pointer_ungrab
+	  (gtk_widget_get_display (GTK_WIDGET (di)),
+	   GDK_CURRENT_TIME);
 
   di->in_drag = FALSE;
 
@@ -966,7 +868,10 @@ bonobo_dock_item_button_changed (GtkWidget      *widget,
       switch (di->orientation)
 	{
 	case GTK_ORIENTATION_HORIZONTAL:
-	  in_handle = event->x < DRAG_HANDLE_SIZE;
+	  if (gtk_widget_get_direction (widget) == GTK_TEXT_DIR_LTR)
+	    in_handle = event->x < DRAG_HANDLE_SIZE;
+	  else
+	    in_handle = event->x > widget->allocation.width - DRAG_HANDLE_SIZE;
 	  break;
 	case GTK_ORIENTATION_VERTICAL:
 	  in_handle = event->y < DRAG_HANDLE_SIZE;
@@ -1022,12 +927,8 @@ bonobo_dock_item_motion (GtkWidget      *widget,
   if (event->window != di->bin_window)
     return FALSE;
 
-#ifdef HAVE_GTK_MULTIHEAD
-  root_window = gdk_screen_get_root_window (
-			gdk_drawable_get_screen (GDK_DRAWABLE (event->window)));
-#else
-  root_window = gdk_get_default_root_window ();
-#endif
+  root_window = gdk_screen_get_root_window
+	  (gdk_drawable_get_screen (GDK_DRAWABLE (event->window)));
 
   gdk_window_get_pointer (root_window, &new_x, &new_y, NULL);
   
@@ -1430,7 +1331,9 @@ bonobo_dock_item_grab_pointer (BonoboDockItem *item)
 
   item->in_drag = TRUE;
 
-  fleur = gdk_cursor_new (GDK_FLEUR);
+  fleur = gdk_cursor_new_for_display
+	  (gtk_widget_get_display (GTK_WIDGET (item)),
+	   GDK_FLEUR);
 
   /* Hm, not sure this is the right thing to do, but it seems to work.  */
   while (gdk_pointer_grab (item->bin_window,
