@@ -1820,63 +1820,3 @@ bonobo_dock_handle_key_nav (BonoboDock     *dock,
 
   return TRUE;
 }
-
-void
-bonobo_dock_focus_roll (BonoboDock *dock)
-{
-	GList *focusable = NULL;
-	GList *l, *bands = NULL, *grips = NULL;
-
-	bands = NULL;
-	bands = g_list_concat (bands, g_list_copy (dock->top_bands));
-	bands = g_list_concat (bands, g_list_copy (dock->bottom_bands));
-	bands = g_list_concat (bands, g_list_copy (dock->right_bands));
-	bands = g_list_concat (bands, g_list_copy (dock->left_bands));
-
-	for (l = bands; l; l = l->next) {
-		GList *l2, *children;
-
-		children = gtk_container_get_children (l->data);
-		
-		for (l2 = children; l2; l2 = l2->next) {
-			GtkWidget *grip;
-
-			if (BONOBO_IS_DOCK_ITEM (l2->data) &&
-			    (grip = bonobo_dock_item_get_grip (BONOBO_DOCK_ITEM (l2->data))))
-				grips = g_list_prepend (grips, grip);
-		}
-	}
-
-	g_list_free (bands);
-
-	for (l = dock->floating_children; l; l = l->next) {
-		GtkWidget *grip;
-
-		if (BONOBO_IS_DOCK_ITEM (l->data) &&
-		    (grip = bonobo_dock_item_get_grip (BONOBO_DOCK_ITEM (l->data))))
-			grips = g_list_prepend (grips, grip);
-	}
-
-	for (l = grips; l; l = l->next) {
-		if (GTK_WIDGET_DRAWABLE (l->data) &&
-		    GTK_WIDGET_CAN_FOCUS (l->data))
-			focusable = g_list_prepend (focusable, l->data);
-	}
-
-	g_list_free (grips);
-
-	for (l = focusable; l; l = l->next) {
-		if (GTK_WIDGET_HAS_FOCUS (l->data))
-			break;
-	}
-
-	if (!l || l->next == NULL)
-		l = focusable;
-	else
-		l = l->next;
-	
-	if (l)
-		gtk_widget_grab_focus (l->data);
-
-	g_list_free (focusable);
-}
